@@ -80,13 +80,7 @@ module Sass
   #
   # `type`: `String`
   # : The user-friendly name of the type of the callable.
-  #
-  # `origin`: `Symbol`
-  # : From whence comes the callable: `:stylesheet`, `:builtin`, `:css`
-  #   A callable with an origin of `:stylesheet` was defined in the stylesheet itself.
-  #   A callable with an origin of `:builtin` was defined in ruby.
-  #   A callable (function) with an origin of `:css` returns a function call with arguments to CSS.
-  Callable = Struct.new(:name, :args, :splat, :environment, :tree, :has_content, :type, :origin)
+  Callable = Struct.new(:name, :args, :splat, :environment, :tree, :has_content, :type)
 
   # This class handles the parsing and compilation of the Sass template.
   # Example usage:
@@ -322,7 +316,8 @@ module Sass
                 end
     end
 
-    # Returns the original encoding of the document.
+    # Returns the original encoding of the document,
+    # or `nil` under Ruby 1.8.
     #
     # @return [Encoding, nil]
     # @raise [Encoding::UndefinedConversionError] if the source encoding
@@ -375,7 +370,7 @@ Error generating source map: couldn't determine public URL for "#{filename}".
   Without a public URL, there's nothing for the source map to link to.
   An importer was not set for this file.
 ERR
-      elsif Sass::Util.silence_sass_warnings do
+      elsif Sass::Util.silence_warnings do
               sourcemap_dir = nil if @options[:sourcemap] == :file
               importer.public_url(filename, sourcemap_dir).nil?
             end
@@ -391,7 +386,7 @@ ERR
       rendered << "\n" if rendered[-1] != ?\n
       rendered << "\n" unless compressed
       rendered << "/*# sourceMappingURL="
-      rendered << URI::DEFAULT_PARSER.escape(sourcemap_uri)
+      rendered << Sass::Util.escape_uri(sourcemap_uri)
       rendered << " */\n"
       return rendered, sourcemap
     end
@@ -499,6 +494,7 @@ END
       lines
     end
 
+    # @comment
     def try_comment(line, last, tab_str, comment_tab_str, index)
       return unless last && last.comment?
       # Nested comment stuff must be at least one whitespace char deeper
@@ -524,6 +520,10 @@ MSG
       nodes = []
       while (line = arr[i]) && line.tabs >= base
         if line.tabs > base
+          raise SyntaxError.new(
+            "The line was indented #{line.tabs - base} levels deeper than the previous line.",
+            :line => line.index) if line.tabs > base + 1
+
           nodes.last.children, i = tree(arr, i)
         else
           nodes << line
@@ -695,14 +695,7 @@ WARNING
       end
 
       name = line.text[0...scanner.pos]
-      could_be_property =
-        if name.start_with?('--')
-          (scanned = scanner.scan(/\s*:/))
-        else
-          (scanned = scanner.scan(/\s*:(?:\s+|$)/))
-        end
-
-      if could_be_property # test for a property
+      if (scanned = scanner.scan(/\s*:(?:\s+|$)/)) # test for a property
         offset += scanned.length
         property = parse_property(name, res, scanner.rest, :new, line, offset)
         property.name_source_range = ident_range
@@ -725,33 +718,26 @@ WARNING
       end
     end
 
+    # @comment
+    #   rubocop:disable ParameterLists
     def parse_property(name, parsed_name, value, prop, line, start_offset)
-
-      if name.start_with?('--')
-        unless line.children.empty?
-          raise SyntaxError.new("Illegal nesting: Nothing may be nested beneath custom properties.",
-            :line => @line + 1)
-        end
-
-        parser = Sass::SCSS::Parser.new(value,
-          @options[:filename], @options[:importer],
-          @line, to_parser_offset(@offset))
-        parsed_value = parser.parse_declaration_value
-        end_offset = start_offset + value.length
-      elsif value.strip.empty?
-        parsed_value = [Sass::Script::Tree::Literal.new(Sass::Script::Value::String.new(""))]
+      # rubocop:enable ParameterLists
+      if value.strip.empty?
+        expr = Sass::Script::Tree::Literal.new(Sass::Script::Value::String.new(""))
         end_offset = start_offset
       else
-        expr = parse_script(value, :offset => to_parser_offset(start_offset))
+        expr = parse_script(value,
+          :offset => to_parser_offset(start_offset),
+          :css_variable => name.start_with?("--"))
         end_offset = expr.source_range.end_pos.offset - 1
-        parsed_value = [expr]
       end
-      node = Tree::PropNode.new(parse_interp(name), parsed_value, prop)
+
+      node = Tree::PropNode.new(parse_interp(name), expr, prop)
       node.value_source_range = Sass::Source::Range.new(
         Sass::Source::Position.new(line.index, to_parser_offset(start_offset)),
         Sass::Source::Position.new(line.index, to_parser_offset(end_offset)),
         @options[:filename], @options[:importer])
-      if !node.custom_property? && value.strip.empty? && line.children.empty?
+      if value.strip.empty? && line.children.empty?
         raise SyntaxError.new(
           "Invalid property: \"#{node.declaration}\" (no value)." +
           node.pseudo_class_selector_message)
@@ -1034,6 +1020,8 @@ WARNING
       values
     end
 
+    # @comment
+    #   rubocop:disable MethodLength
     def parse_import_arg(scanner, offset)
       return if scanner.eos?
 
@@ -1108,6 +1096,8 @@ WARNING
       end
       node
     end
+    # @comment
+    #   rubocop:enable MethodLength
 
     def parse_mixin_directive(parent, line, root, value, offset)
       parse_mixin_definition(line)
@@ -1164,9 +1154,9 @@ WARNING
     end
 
     def parse_script(script, options = {})
-      line = options[:line] || @line
-      offset = options[:offset] || @offset + 1
-      Script.parse(script, line, offset, @options)
+      line = options.delete(:line) || @line
+      offset = options.delete(:offset) || @offset + 1
+      Script.parse(script, line, offset, @options.merge(options))
     end
 
     def format_comment_text(text, silent)
